@@ -566,7 +566,7 @@ demarshal_value(CORBA_TypeCode tc, gconstpointer *val)
 	switch (tc->subtypes[0]->kind) {
 	case CORBA_tk_char:
 	case CORBA_tk_octet:
-	    ret = PyString_FromStringAndSize(sval->_buffer, sval->_length);
+	    ret = PyString_FromStringAndSize((char *) sval->_buffer, sval->_length);
 	    break;
 	default: {
 	    PyObject *list;
